@@ -1,3 +1,4 @@
+import sys
 # movies = ["The Holy Grail", "The Life of Brian", "The Meaning of Life"]
 # movies.insert(1,1975);
 # movies.insert(3, 1979);
@@ -14,13 +15,14 @@
 #     ["Pink", "Coffee","Lovely"]
 # ]
 
-def traverse_list(list_par, level):
+def traverse_list(list_par, apply_indent=False,level=-1, fh=sys.stdout):
     if isinstance(list_par, list):
         for list_item in list_par:
-            traverse_list(list_item, level+1)
+            traverse_list(list_item,apply_indent, level+1, fh)
     else:
         indent="";
-        for time in range(level):
-            # indent += "\t"
-            print(end="\t")
-        print(indent+str(list_par))
\ No newline at end of file
+        if apply_indent:
+            for time in range(level):
+                indent += "\t"
+                # print(end="\t")
+        print(indent+str(list_par), file=fh)
\ No newline at end of file
